.. note::
    :class: sphx-glr-download-link-note

    Click :ref:`here <sphx_glr_download_auto_examples_data_plot_specific.py>` to download the full example code
.. rst-class:: sphx-glr-example-title

.. _sphx_glr_auto_examples_data_plot_specific.py:


===============
Specific images
===============




.. code-block:: python

    import numpy as np
    import matplotlib.pyplot as plt
    import matplotlib

    from skimage import data

    matplotlib.rcParams['font.size'] = 18







Stereo images
=============



.. code-block:: python



    fig, axes = plt.subplots(1, 2, figsize=(8, 4))
    ax = axes.ravel()

    images = data.stereo_motorcycle()
    ax[0].imshow(images[0])
    ax[1].imshow(images[1])

    fig.tight_layout()
    plt.show()




.. image:: /auto_examples/data/images/sphx_glr_plot_specific_001.png
    :class: sphx-glr-single-img




Faces and non-faces dataset
===========================

A sample of 20 over 200 images is displayed.



.. code-block:: python



    fig, axes = plt.subplots(4, 5, figsize=(20, 20))
    ax = axes.ravel()
    images = data.lfw_subset()
    for i in range(20):
        ax[i].imshow(images[90+i], cmap=plt.cm.gray)
        ax[i].axis('off')
    fig.tight_layout()
    plt.show()



.. image:: /auto_examples/data/images/sphx_glr_plot_specific_002.png
    :class: sphx-glr-single-img




**Total running time of the script:** ( 0 minutes  0.550 seconds)


.. _sphx_glr_download_auto_examples_data_plot_specific.py:


.. only :: html

 .. container:: sphx-glr-footer
    :class: sphx-glr-footer-example



  .. container:: sphx-glr-download

     :download:`Download Python source code: plot_specific.py <plot_specific.py>`



  .. container:: sphx-glr-download

     :download:`Download Jupyter notebook: plot_specific.ipynb <plot_specific.ipynb>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.readthedocs.io>`_
